elephant.test.test_spike_train_dissimilarity module — Elephant 0.5.0 documentation

# elephant.test.test_spike_train_dissimilarity module

Tests for the spike train dissimilarity measures module.

class `elephant.test.test_spike_train_dissimilarity.` `TimeScaleDependSpikeTrainDissimMeasures_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_van_rossum_distance`()
  `test_victor_purpura_algorithm_comparison`()
  `test_victor_purpura_distance_fast`()
  `test_victor_purpura_distance_intuitive`()
  `test_wrong_input`()